@@ -1,6 +1,6 @@
-use fluvio_smartstream::{smartstream, Record, RecordData, Result};
+use fluvio_smartmodule::{smartmodule, Record, RecordData, Result};
 
-#[smartstream(map)]
+#[smartmodule(map)]
 pub fn my_map(_record: &Record) -> Result<(Option<RecordData>, RecordData)> {
     unimplemented!()
 }
